.. image:: https://badge.fury.io/py/python-dwca-reader.svg
    :target: https://badge.fury.io/py/python-dwca-reader

.. image:: https://travis-ci.org/BelgianBiodiversityPlatform/python-dwca-reader.svg?branch=master
    :target: https://travis-ci.org/BelgianBiodiversityPlatform/python-dwca-reader

.. image:: https://readthedocs.org/projects/python-dwca-reader/badge/?version=latest
	:target: http://python-dwca-reader.readthedocs.org/en/latest/?badge=latest
	:alt: Documentation Status

What is it ?
============

A simple Python class to read `Darwin Core Archive`_ (DwC-A) files, including data downloads from `GBIF`_.

Documentation
-------------

The documentation has moved to: http://python-dwca-reader.readthedocs.org/.

.. _Darwin Core Archive: http://en.wikipedia.org/wiki/Darwin_Core_Archive
.. _GBIF: https://www.gbif.org
